@@ -9,11 +9,27 @@ use Carp 'croak';
 
 use File::Find;
 
-use vars qw(@ISA @EXPORT $VERSION);
+use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
 @ISA    = qw(Test::Builder::Module);
-@EXPORT = @Test::More::EXPORT;
+@EXPORT = (@Test::More::EXPORT, 'run_this_test_program');
 
-BEGIN { $ENV{TEST_AGGREGATE} = 1 };
+BEGIN { 
+    $ENV{TEST_AGGREGATE} = 1;
+    *CORE::GLOBAL::exit = sub {
+        my ($package, $filename, $line) = caller;
+        print STDERR <<"        END_EXIT_WARNING";
+********
+WARNING!
+exit called under Test::Aggregate at:
+File:    $filename
+Package: $package
+Line:    $line
+WARNING!
+********
+        END_EXIT_WARNING
+        exit(@_);
+    };
+};
 
 END {   # for VMS
     delete $ENV{TEST_AGGREGATE};
@@ -32,11 +48,11 @@ Test::Aggregate - Aggregate C<*.t> tests to make them run faster.
 
 =head1 VERSION
 
-Version 0.34_09
+Version 0.35_01
 
 =cut
 
-$VERSION = '0.34_09';
+$VERSION = '0.35_01';
 
 =head1 SYNOPSIS
 
@@ -47,6 +63,8 @@ $VERSION = '0.34_09';
     } );
     $tests->run;
 
+    ok $some_data, 'Test::Aggregate also re-exports Test::More functions';
+
 =head1 DESCRIPTION
 
 B<WARNING>:  this is ALPHA code.  The interface is not guaranteed to be
@@ -73,12 +91,26 @@ your regular test directory (C<t/> is the standard):
  });
  $tests->run;
 
+ ok $some_data, 'Test::Aggregate also re-exports Test::More functions';
+
 Take your simplest tests and move them, one by one, into the new test
 directory and keep running the C<Test::Aggregate> program.  You'll find some
 tests will not run in a shared environment like this.  You can either fix the
 tests or simply leave them in your regular test directory.  See how this
 distribution's tests are organized for an example.
 
+Note that C<Test::Aggregate> also exports all exported functions from
+C<Test::More>, allowing you to run other tests after the aggregated tests have
+run.
+
+ use Test::Aggregate;
+ my $other_test_dir = 'aggregate_tests';
+ my $tests = Test::Aggregate->new( {
+    dirs => $other_test_dir
+ });
+ $tests->run;
+ ok !(-f 't/data/tmp.txt'), '... and our temp file should be deleted';
+
 Some tests cannot run in an aggregate environment.  These may include
 test for this with the C<< $ENV{TEST_AGGREGATE} >> variable:
 
@@ -436,7 +468,7 @@ sub run {
     my $builder = Test::Builder->new;
 
     # some tests may have been run in BEGIN blocks
-    $builder->{TEST_AGGREGATE_last_test} = @{ $builder->{Test_Results} } || 0;
+    $builder->{'Test::Aggregate::Builder'}{last_test} = @{ $builder->{Test_Results} } || 0;
 
     my $current_test = 0;
     my @packages     = $self->_packages;
@@ -445,7 +477,7 @@ sub run {
         $current_test++;
         my ( $test, $package ) = @$data;
         $self->_setup->() if $self->_setup;
-        _run_this_test_program( $package => $test, $current_test, $total_tests, 2 );
+        run_this_test_program( $package => $test, $current_test, $total_tests, 2 );
         if ( my $error = $@ ) {
             Test::More::ok( 0, "Error running ($test):  $error" );
         }
@@ -463,8 +495,11 @@ sub _any_tests_failed {
     my $failed  = 0; 
     my $builder = Test::Builder->new;
     my @summary = $builder->summary;
-    foreach my $passed (@summary[ $builder->{TEST_AGGREGATE_last_test} ..
-        $builder->current_test - 1 ]) {
+    foreach my $passed (
+        @summary[ $builder->{'Test::Aggregate::Builder'}{last_test} 
+            ..
+        $builder->current_test - 1 ]
+    ) {
         if (not $passed) {
             $failed = 1;
             last;
@@ -473,13 +508,14 @@ sub _any_tests_failed {
     return $failed;
 }
 
-sub _run_this_test_program {
+sub run_this_test_program {
     my $builder = Test::Builder->new;
     my ( $package, $test, $current_test, $num_tests, $verbose ) = @_;
     Test::More::diag("******** running tests for $test ********") if $ENV{TEST_VERBOSE};
     my $error = eval { 
-        if ( my $reason = $Test::Aggregate::Builder::SKIP_REASON_FOR{$package} ) {
-            Test::Builder->new->skip($reason);
+        my $builder = Test::Builder->new;
+        if ( my $reason = $builder->{'Test::Aggregate::Builder'}{skip_reason_for}{$package} ) {
+            $builder->skip($reason);
             return;
         }
         else {
@@ -493,7 +529,7 @@ sub _run_this_test_program {
             local $|   = $|;
             local %SIG = %SIG;
             use warnings 'uninitialized';
-            $Test::Aggregate::Builder::FILE_FOR{$package} = $test;
+            $builder->{'Test::Aggregate::Builder'}{file_for}{$package} = $test;
             eval { $package->run_the_tests };
             $@;
         }
@@ -516,7 +552,7 @@ sub _run_this_test_program {
             $builder->{TEST_MOST_test_failed} = 0;
         }
     }
-    $builder->{TEST_AGGREGATE_last_test} = $builder->current_test;
+    $builder->{'Test::Aggregate::Builder'}{last_test} = $builder->current_test;
 
     return unless $error;
 }
@@ -584,7 +620,7 @@ $findbin
         if ( $setup ) {
             $code .= "    $setup->('$test');\n";
         }
-        $code .= qq{    Test::Aggregate::_run_this_test_program( $package => "$test", $current_test, $total_tests, $verbose );};
+        $code .= qq{    run_this_test_program( $package => "$test", $current_test, $total_tests, $verbose );};
 
         if ( $teardown ) {
             $code .= "    $teardown->('$test');\n";
@@ -679,21 +715,25 @@ BEGIN {
     *Test::NoWarnings::had_no_warnings = sub { };
     *Test::NoWarnings::import = sub {
         my $callpack = caller();
-        if ( $Test::Aggregate::Builder::PLAN_FOR{$callpack} ) {
-            $Test::Aggregate::Builder::PLAN_FOR{$callpack}--;
+        my $ta_builder = $BUILDER->{'Test::Aggregate::Builder'};
+        if ( $ta_builder->{plan_for}{$callpack} ) {
+            $ta_builder->{plan_for}{$callpack}--;
         }
-        $Test::Aggregate::Builder::TEST_NOWARNINGS_LOADED{$callpack} = 1;
+        $ta_builder->{test_nowarnings_loaded}{$callpack} = 1;
     };
 }
         END_CODE
     }
 
     return <<"    END_CODE";
+use Test::Aggregate;
 use Test::Aggregate::Builder;
-BEGIN { \$Test::Aggregate::Builder::CHECK_PLAN = $check_plan };
+my \$BUILDER;
+BEGIN { 
+    \$BUILDER = Test::Builder->new;
+    \$BUILDER->{'Test::Aggregate::Builder'}{check_plan} = $check_plan 
+};
 $disable_test_nowarnings;
-
-my \$BUILDER = Test::Builder->new;
     END_CODE
 }
 
@@ -811,6 +851,12 @@ tests, there is no need to run them with this.  Otherwise:
 
 =over 4
 
+=item * C<exit>
+
+Don't call exit() in your aggregated tests.  We now warn very verbosely if
+this is done, but we still exit on the assumption that further tests cannot
+run.
+
 =item * C<__END__> and C<__DATA__> tokens.
 
 These won't work and the tests will call BAIL_OUT() if these tokens are seen.
